@@ -1,10 +1,11 @@
-
 # Encoding UTF-8 not well supported on Windows, skip tests
 if (Sys.info()[["sysname"]] == "Windows") {
   exit_file("Cannot test this on Windows")
 }
 
-if (getRversion() >= as.package_version("4.1.0")) exit_file("skip remainder")
+if (getRversion() >= as.package_version("4.1.0")) {
+  exit_file("skip remainder")
+}
 
 # Exit if no internet
 if (!curl::has_internet()) {
@@ -12,8 +13,8 @@ if (!curl::has_internet()) {
 }
 
 # Exit unless opted in
-if (Sys.getenv("RunAllGtrendsRTests", unset="") == "") {
-    exit_file("Skipping tests not opted into.")
+if (Sys.getenv("RunAllGtrendsRTests", unset = "") == "") {
+  exit_file("Skipping tests not opted into.")
 }
 
 # Japanese
